-- Rename job status QUEUED → TODO
ALTER TABLE jobs
    MODIFY COLUMN status ENUM('TODO', 'QUEUED', 'RUNNING', 'SUCCESS', 'FAILED', 'DEAD') NOT NULL DEFAULT 'TODO';

UPDATE jobs SET status = 'TODO' WHERE status = 'QUEUED';

ALTER TABLE jobs
    MODIFY COLUMN status ENUM('TODO', 'RUNNING', 'SUCCESS', 'FAILED', 'DEAD') NOT NULL DEFAULT 'TODO';
